release library

This utility :

  • Gets what has been commited this the latest version.
  • Generates a changelog.
  • Bumps the version.
  • Makes a git tag.
  • Commit and push the changes.
  • Create a Github release.

Classes

AskIgnoredScopesTypesHashesProcess
A process that asks the user to enter a comma separated list of scopes, types and hashes to ignore.
ChangeLogEntry
A simple changelog entry, containing sub-entries.
Cmd
A simple command line utility.
CommitAndPushProcess
A process that asks the user to commit and push the changes.
CommitPushResult
The result of the CommitAndPushProcess.
ConventionalCommitWithHash
Just a wrapper for a ConventionalCommit holding a hash.
CreateGithubReleaseProcess
A process that asks the user to create a Github release.
CreateTagProcess
A process that asks the user to create a tag.
FindChangesProcess
A process that finds changes since the last tag.
FlatpakUpdated
The result of the UpdateFlatpakProcess.
GithubReleaseCreated
The result of the CreateGithubReleaseProcess.
IgnoredScopesTypesHashes
The result of the AskIgnoredScopesTypesHashesProcess.
MarkdownEntryContent
The result of the WriteChangelogProcess.
NewVersion
The result of the NewVersionProcess.
NewVersionProcess
A process that asks the user for a new version.
PubPublished
The result of the PubPublishProcess.
PubPublishProcess
A process that asks the user to publish to pub.dev.
PubspecContent
The result of the ReadPubspecProcess.
PubspecUpdated
The result of the UpdatePubspecProcess.
ReadPubspecProcess
A process that reads the pubspec.yaml file.
Release
The release utility main class.
ReleaseProcessResult
The result of a ReleaseProcess.
ReleaseProcessResultCancelled
The result of a cancelled ReleaseProcess.
ReleaseProcessResultError
The result of a failed ReleaseProcess.
ReleaseProcessResultSuccess<T extends ReleaseProcessResultValue>
The result of a successful ReleaseProcess.
SnapcraftUpdated
The result of the UpdateSnapcraftProcess.
TagCreated
The result of the CreateTagProcess.
UpdateFlatpakProcess
A process that updates the flatpak.yaml file.
UpdatePubspecProcess
A process that updates the pubspec.yaml file.
UpdateSnapcraftProcess
A process that updates the snapcraft.yaml file.
WriteChangelogProcess
A process that writes the CHANGELOG.md file.

Mixins

PubspecDependantReleaseProcess
A process that can be configured through the pubspec.yaml file.
ReleaseProcess
A process that can be run by the Release utility.
ReleaseProcessResultValue
A value used by a ReleaseProcess.