ReleaseProcessResultError class

The result of a failed ReleaseProcess.

Inheritance

Constructors

ReleaseProcessResultError({required dynamic error, StackTrace? stackTrace})
Creates a new ReleaseProcessResultError instance.

Properties

error → dynamic
The error.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stackTrace StackTrace
The stack trace.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited